==> e2e-cypress-dsl-9.7.21.zip: dsl/pages/folder-details-page.js <==
import FolderTemplatesListPage from './folder-templates-list-page';
import ReleasesListPage from './releases-list-page';
import ReleaseGroupsPage from './release-groups-page';
import {FolderDashboardsPage, FolderPermissionsPage} from './folders';
import FolderVariablesPage from './folder-variables-page';
import ConfigurationPage from './configuration-page';
import DeliveryPatternsPage from '../../../../../../../../modules/xlr-release-delivery-module/src/test/javascript/e2e/cypress/support/delivery-pattern-lists-page';

export default class FolderDetailsPage {

    openTemplates() {
        cy.get(`folders-detail .a[tooltip="'Templates'"]`).click({force:true});
        return new FolderTemplatesListPage();
    }

    openReleases() {
        cy.get(`folders-detail .a[tooltip="'Releases'"]`).click();
        return new ReleasesListPage();
    }

    openDeliveryPatterns() {
        cy.get(`folders-detail .a[tooltip="'Patterns'"]`).click();
        return new DeliveryPatternsPage();
    }

    openGroups() {
        cy.get(`folders-detail .a[tooltip="'Groups'"]`).click();
        return new ReleaseGroupsPage();
    }

    openDashboards() {
        cy.get(`folders-detail .a[tooltip="'Dashboards'"]`).click();
        return new FolderDashboardsPage();
    }

    openFolderVariables() {
        cy.server();
        cy.route('**/variables*').as('getVariables');
        cy.get(`folders-detail .a[tooltip="'Variables'"]`).click();
        cy.wait('@getVariables');
        return new FolderVariablesPage();
    }

    openPermissions() {
        cy
            .doWithRetry(
                () => cy
                    .get(`folders-detail .a[tooltip="'Teams & Permissions'"]:visible`).should('exist')
                    .get(`folders-detail .a[tooltip="'Teams & Permissions'"]`).click({force: true}),
                '#permissions .table:visible'
            );
        return new FolderPermissionsPage();
    }

    getPermissions() {
        return new FolderPermissionsPage();
    }

    openConfigurations() {
        cy.get(`folders-detail .a[tooltip="'Configuration'"]`).click();
        return new ConfigurationPage();
    }
}

==> e2e-cypress-dsl-10.2.2.zip: dsl/pages/folder-details-page.js <==
import FolderTemplatesListPage from './folder-templates-list-page';
import ReleasesListPage from './releases-list-page';
import ReleaseGroupsPage from './release-groups-page';
import {FolderDashboardsPage, FolderPermissionsPage} from './folders';
import FolderVariablesPage from './folder-variables-page';
import ConfigurationPage from './configuration-page';
import DeliveryPatternsPage from '../../../../../../../../modules/xlr-release-delivery-module/src/test/javascript/e2e/cypress/support/delivery-pattern-lists-page';
import DeliveriesPage from '../../../../../../../../modules/xlr-release-delivery-module/src/test/javascript/e2e/cypress/support/deliveries-list-page';

export default class FolderDetailsPage {

    open(tab) {
        cy.get(`.folder-tabs span:contains(${tab})`).click();
    }
    openTemplates() {
        this.open('Templates');
        return new FolderTemplatesListPage();
    }

    openReleases() {
        this.open('Releases');
        return new ReleasesListPage();
    }

    openDeliveryPatterns() {
        this.open('Patterns');
        return new DeliveryPatternsPage();
    }

    openDeliveries() {
        this.open('Deliveries');
        return new DeliveriesPage();
    }

    openGroups() {
        this.open('Groups');
        return new ReleaseGroupsPage();
    }

    openDashboards() {
        this.open('Dashboards');
        return new FolderDashboardsPage();
    }

    openFolderVariables() {
        cy.server();
        cy.route('**/variables*').as('getVariables');
        this.open('Variables');
        cy.wait('@getVariables');
        return new FolderVariablesPage();
    }

    openPermissions() {
        this.open('Teams & Permissions');
        return new FolderPermissionsPage();
    }

    getPermissions() {
        return new FolderPermissionsPage();
    }

    openConfigurations() {
        this.open('Configuration');
        return new ConfigurationPage();
    }
}
